from setuptools import setup, find_packages


data = {'author': 'Nicolas Wack',
 'author_email': 'wackou@gmail.com',
 'classifiers': ['Development Status :: 5 - Production/Stable',
                 'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
                 'Operating System :: OS Independent',
                 'Intended Audience :: Developers',
                 'Programming Language :: Python :: 2',
                 'Programming Language :: Python :: 2.6',
                 'Programming Language :: Python :: 2.7',
                 'Programming Language :: Python :: 3',
                 'Programming Language :: Python :: 3.2',
                 'Topic :: Multimedia',
                 'Topic :: Software Development :: Libraries :: Python Modules'],
 'data_files': [],
 'description': 'GuessIt - a library for guessing information from video files.',
 'entry_points': {'console_scripts': ['guessit = guessit.__main__:main']},
 'extras_require': {'language_detection': ['guess-language>=0.2']},
 'include_package_data': True,
 'install_requires': [],
 'keywords': 'smewt media video metadata python library',
 'license': 'LGPLv3',
 'long_description': 'GuessIt\n=======\n\n.. image:: https://pypip.in/v/guessit/badge.png\n   :target: https://crate.io/packages/guessit\n\n.. image:: https://secure.travis-ci.org/wackou/guessit.png?branch=master\n   :target: http://travis-ci.org/wackou/guessit\n\nGuessIt is a python library that tries to extract as much information as\npossible from a video file.\n\nIt has a very powerful filename matcher that allows to guess a lot of\nmetadata from a video using only its filename. This matcher works with\nboth movies and tv shows episodes.\n\nFor example, GuessIt can do the following::\n\n    $ python -m guessit "Treme.1x03.Right.Place,.Wrong.Time.HDTV.XviD-NoTV.avi"\n    For: Treme.1x03.Right.Place,.Wrong.Time.HDTV.XviD-NoTV.avi\n    GuessIt found: {\n        [1.00] "mimetype": "video/x-msvideo",\n        [0.80] "episodeNumber": 3,\n        [0.80] "videoCodec": "XviD",\n        [1.00] "container": "avi",\n        [1.00] "format": "HDTV",\n        [0.70] "series": "Treme",\n        [0.50] "title": "Right Place, Wrong Time",\n        [0.80] "releaseGroup": "NoTV",\n        [0.80] "season": 1,\n        [1.00] "type": "episode"\n    }\n\n\n\nFeatures\n--------\n\nAt the moment, the filename matcher is able to recognize the following\nproperty types::\n\n    [ title,                             # for movies and episodes\n      series, season, episodeNumber,     # for episodes only\n      date, year,                        # \'date\' instance of datetime.date\n      language, subtitleLanguage,        # instances of guessit.Language\n      container, format, is3D,\n      videoCodec, audioCodec,\n      audioChannels, screenSize,\n      releaseGroup, website,\n      cdNumber, cdNumberTotal,\n      filmNumber, filmSeries,\n      bonusNumber, edition,\n      idNumber,                          # tries to identify a hash or a serial number\n      other\n      ]\n\n\nGuessIt also allows you to compute a whole lof of hashes from a file,\nnamely all the ones you can find in the hashlib python module (md5,\nsha1, ...), but also the Media Player Classic hash that is used (amongst\nothers) by OpenSubtitles and SMPlayer, as well as the ed2k hash.\n\nIf you have the \'guess-language\' python module installed, GuessIt can also\nanalyze a subtitle file\'s contents and detect which language it is written in.\n\n\nInstall\n-------\n\nInstalling GuessIt is simple with `pip <http://www.pip-installer.org/>`_::\n\n    $ pip install guessit\n\nor, with `easy_install <http://pypi.python.org/pypi/setuptools>`_::\n\n    $ easy_install guessit\n\nBut, you really `shouldn\'t do that <http://www.pip-installer.org/en/latest/other-tools.html#pip-compared-to-easy-install>`_.\n\n\n\nSupport\n-------\n\nThe project website for GuessIt is hosted at `ReadTheDocs <http://guessit.readthedocs.org/>`_.\nThere you will also find the User guide and Developer documentation.\n\nThis project is hosted on GitHub: `<https://github.com/wackou/guessit>`_\n\nPlease report issues via the `bug tracker <https://github.com/wackou/guessit/issues>`_.\n\n\nContribute\n----------\n\nGuessIt is under active development, and contributions are more than welcome!\n\n#. Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug.\n   There is a Contributor Friendly tag for issues that should be ideal for people who are not very\n   familiar with the codebase yet.\n#. Fork `the repository`_ on Github to start making your changes to the **master**\n   branch (or branch off of it).\n#. Write a test which shows that the bug was fixed or that the feature works as expected.\n#. Send a pull request and bug the maintainer until it gets merged and published. :)\n\n.. _the repository: https://github.com/wackou/guessit\n\nLicense\n-------\n\nGuessIt is licensed under the `LGPLv3 license <http://www.gnu.org/licenses/lgpl.html>`_.\n\n\n.. This is your project NEWS file which will contain the release notes.\n.. Example: http://www.python.org/download/releases/2.6/NEWS.txt\n.. The content of this file, along with README.rst, will appear in your\n.. project\'s PyPI page.\n\nHistory\n=======\n\n\n\n0.6.2 (2013-11-08)\n------------------\n\n* Added support for nfo files\n* GuessIt can now output advanced information as json (\'-a\' on the command line)\n* Better language detection\n* Added new property: \'is3D\'\n\n\n0.6.1 (2013-09-18)\n------------------\n\n* New property "idNumber" that tries to identify a hash value or a\n  serial number\n* The usual bugfixes\n\n\n0.6 (2013-07-16)\n----------------\n\n* Better packaging: unittests and doc included in source tarball\n* Fixes everywhere: unicode, release group detection, language detection, ...\n* A few speed optimizations\n\n\n0.5.4 (2013-02-11)\n------------------\n\n* guessit can be installed as a system wide script (thanks @dplarson)\n* Enhanced logging facilities\n* Fixes for episode number and country detection\n\n\n0.5.3 (2012-11-01)\n------------------\n\n* GuessIt can now optionally act as a wrapper around the \'guess-language\' python\n  module, and thus provide detection of the natural language in which a body of\n  text is written\n\n* Lots of fixes everywhere, mostly for properties and release group detection\n\n\n0.5.2 (2012-10-02)\n------------------\n\n* Much improved auto-detection of filetype\n* Fixed some issues with the detection of release groups\n\n\n0.5.1 (2012-09-23)\n------------------\n\n* now detects \'country\' property; also detect \'year\' property for series\n* more patterns and bugfixes\n\n\n0.5 (2012-07-29)\n----------------\n\n* Python3 compatibility\n* the usual assortment of bugfixes\n\n\n0.4.2 (2012-05-19)\n------------------\n\n* added Language.tmdb language code property for TheMovieDB\n* added ability to recognize list of episodes\n* bugfixes for Language.__nonzero__ and episode regexps\n\n\n0.4.1 (2012-05-12)\n------------------\n\n* bugfixes for unicode, paths on Windows, autodetection, and language issues\n\n\n0.4 (2012-04-28)\n----------------\n\n* much improved language detection, now also detect language variants\n* supports more video filetypes (thanks to Rob McMullen)\n\n\n0.3.1 (2012-03-15)\n------------------\n\n* fixed package installation from PyPI\n* better imports for the transformations (thanks Diaoul!)\n* some small language fixes\n\n0.3 (2012-03-12)\n----------------\n\n* fix to recognize 1080p format (thanks to Jonathan Lauwers)\n\n0.3b2 (2012-03-02)\n------------------\n\n* fixed the package installation\n\n0.3b1 (2012-03-01)\n------------------\n\n* refactored quite a bit, code is much cleaner now\n* fixed quite a few tests\n* re-vamped the documentation, wrote some more\n\n0.2 (2011-05-27)\n----------------\n\n* new parser/matcher completely replaced the old one\n* quite a few more unittests and fixes\n\n\n0.2b1 (2011-05-20)\n------------------\n\n* brand new parser/matcher that is much more flexible and powerful\n* lots of cleaning and a bunch of unittests\n\n\n0.1 (2011-05-10)\n----------------\n\n* fixed a few minor issues & heuristics\n\n\n0.1b2 (2011-03-12)\n------------------\n\n* Added PyPI trove classifiers\n* fixed version number in setup.py\n\n\n0.1b1 (2011-03-12)\n------------------\n\n* first pre-release version; imported from Smewt with a few enhancements already\n  in there.\n',
 'name': 'guessit',
 'packages': ['guessit', 'guessit.transfo', 'guessit.test'],
 'test_suite': 'guessit.test',
 'url': 'http://guessit.readthedocs.org/',
 'version': u'0.6.3'}


setup(**data)